/**
* Cookie plugin
*
* Copyright (c) 2006 Klaus Hartl (stilbuero.de)
* Dual licensed under the MIT and GPL licenses:
* http://www.opensource.org/licenses/mit-license.php
* http://www.gnu.org/licenses/gpl.html
*
*/

/**7
* Create a cookie with the given name and value and other optional parameters.
*
* @example $.cookie('the_cookie', 'the_value');
* @desc Set the value of a cookie.
* @example $.cookie('the_cookie', 'the_value', { expires: 7, path: '/', domain: 'jquery.com', secure: true });
* @desc Create a cookie with all available options.
* @example $.cookie('the_cookie', 'the_value');
* @desc Create a session cookie.
* @example $.cookie('the_cookie', null);
* @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
*       used when the cookie was set.
*
* @param String name The name of the cookie.
* @param String value The value of the cookie.
* @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
* @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
*                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
*                             If set to null or omitted, the cookie will be a session cookie and will not be retained
*                             when the the browser exits.
* @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
* @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
* @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
*                        require a secure protocol (like HTTPS).
* @type undefined
*
* @name $.cookie
* @cat Plugins/Cookie
* @author Klaus Hartl/klaus.hartl@stilbuero.de
*/

/**
* Get the value of a cookie with the given name.
*
* @example $.cookie('the_cookie');
* @desc Get the value of a cookie.
*
* @param String name The name of the cookie.
* @return The value of the cookie.
* @type String
*
* @name $.cookie
* @cat Plugins/Cookie
* @author Klaus Hartl/klaus.hartl@stilbuero.de
*/
jQuery.cookie = function(name, value, options) {
	if (typeof value != 'undefined') { // name and value given, set cookie
		options = options || {};
		if (value === null) {
			value = '';
			options.expires = -1;
		}
		var expires = '';
		if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
			var date;
			if (typeof options.expires == 'number') {
				date = new Date();
				date.setTime(date.getTime() + (options.expires * 60 * 1000));
			} else {
				date = options.expires;
			}
			expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
		}
		// CAUTION: Needed to parenthesize options.path and options.domain
		// in the following expressions, otherwise they evaluate to undefined
		// in the packed version for some reason...
		var path = options.path ? '; path=' + (options.path) : '';
		var domain = options.domain ? '; domain=' + (options.domain) : '';
		var secure = options.secure ? '; secure' : '';
		document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
	} else { // only name given, get cookie
		var cookieValue = null;
		if (document.cookie && document.cookie != '') {
			var cookies = document.cookie.split(';');
			for (var i = 0; i < cookies.length; i++) {
				var cookie = jQuery.trim(cookies[i]);
				// Does this cookie string begin with the name we want?
				if (cookie.substring(0, name.length + 1) == (name + '=')) {
					cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
					break;
				}
			}
		}
		return cookieValue;
	}
};

/* **********************************************
Begin form.select.js
********************************************** */

/*
* Converts form selects to style-able elements using a span for the value, a ul for the options and a wrapper for extra control
* Keeps default form methods intact (automatically updates select, doesn't effect submit, uses label)
* Updates based on selected value on page load
*/

(function ($) {
	$.fn.selectGui = function () {
		var z = 80;
		return this.each(function () {
			var that = {};
			that.label = null;
			that.select = $(this);
			that.wrapper = null;
			that.span = null;
			that.list = null;
			that.events = function() {
				// Show and hide the list
				that.span.click(function() {
					that.slideList();
				});

				// Click an li, update the span value and the select value
				$('li', that.list).click(function() {
					that.markLi($(this));
					that.select.change();
					that.slideList();
				});

				// Hook up the label for default form functionality
				if(that.select.attr('id') !== '') {
					that.label = $('label[for='+that.select.attr('id')+']');
					that.label.click(function(e) {
						that.span.trigger('click');
					});
				}
				that.select.bind('refresh', function() {
					var li = $('li[data-val='+$(this).val()+']', that.list);
					that.markLi(li);
				});

				// Hide the list on clickOff
				$('body').click(function(event) {
					if (!$(event.target).closest(that.wrapper).length && !$(event.target).closest(that.label).length) {
						that.slideList('up');
					}
				});
			};
			that.markLi = function(li) {
				li.addClass('selected').siblings('li').removeClass('selected');
				that.select.val(li.attr('data-val'));
				that.span.text(li.text());
			};
			that.populateList = function() {
				$('option', that.select).each(function() {
					var option = $(this);
					var li = $('<li data-val="'+option.val()+'">'+option.text()+'</li>');
					that.list.append(li);
					if(option.is(':selected')) {
						li.addClass('selected');
					}
				});
			};
			that.slideList = function(direction) {
				if(!direction) {
					direction = null;
				}
				if(direction == 'up') {
					that.list.slideUp();
				} else if(direction == 'down') {
					that.list.slideDown();
				} else {
					that.list.slideToggle();
				}
			};
			that.setup = function() {
				that.select.wrap('<div class="singleselect gui '+that.select.attr('class')+'" style="z-index: '+z+'" />');
				// Make wrapper
				that.wrapper = that.select.parents('.singleselect.gui');
				// Make container for current value
				var selected = $('option:selected', that.select);
				var selected_text = selected.text();
				if(that.select.attr('data-placeholder')) {
					selected_text = that.select.attr('data-placeholder');
				}
				that.span = $('<span>'+selected_text+'</span>');
				that.wrapper.prepend(that.span).prepend('<b />');
				z--;
				// Make list of select options, highlighting the current value
				that.list = $('<ul />');
				that.populateList();
				that.span.after(that.list);
				// Setup events
				that.events();
			};
			//that.setup();
		});
	};
})(jQuery);

/* **********************************************
Begin hint.js
********************************************** */

/**
* Includes a fix for using the back button
* Title default to placeholder for HTML5 support
* @author Remy Sharp
* @url http://remysharp.com/2007/01/25/jquery-tutorial-text-box-hints/
*/

(function ($) {

	$.fn.hint = function (blurClass) {
		if (!blurClass) {
			blurClass = 'blur';
		}

		return this.each(function () {
			var $input = $(this),
			title = $input.attr('placeholder'),
			$form = $(this.form),
			$win = $(window);

			function remove() {
				if ($input.val() === title) {
					$input.val('').removeClass(blurClass);
				}
			}

			// only apply logic if the element has the attribute
			if (title) {
				// on blur, set value to title attr if text is blank

				$input.blur(function () {
					if (this.value === '' || this.value === title) {
						$input.val(title).addClass(blurClass);
					}
				}).focus(remove).blur(); // now change all inputs to title

				// clear the pre-defined text when form is submitted
				$form.submit(remove);
				$win.unload(remove); // handles Firefox's autocomplete
			}
		});
	};

})(jQuery);

/* **********************************************
Begin jquery.flexslider-min.js
********************************************** */

/*
* jQuery FlexSlider v2.0
* Copyright 2013 WooThemes
* Contributing Author: Tyler Smith
*/
;(function(d){d.flexslider=function(h,k){var a=d(h),c=d.extend({},d.flexslider.defaults,k),e=c.namespace,o="ontouchstart"in window||window.DocumentTouch&&document instanceof DocumentTouch,s=o?"touchend":"click",l="vertical"===c.direction,m=c.reverse,i=0<c.itemWidth,p="fade"===c.animation,r=""!==c.asNavFor,f={};d.data(h,"flexslider",a);f={init:function(){a.animating=!1;a.currentSlide=c.startAt;a.animatingTo=a.currentSlide;a.atEnd=0===a.currentSlide||a.currentSlide===a.last;a.containerSelector=c.selector.substr(0,
c.selector.search(" "));a.slides=d(c.selector,a);a.container=d(a.containerSelector,a);a.count=a.slides.length;a.syncExists=0<d(c.sync).length;"slide"===c.animation&&(c.animation="swing");a.prop=l?"top":"marginLeft";a.args={};a.manualPause=!1;a.transitions=!c.video&&!p&&c.useCSS&&function(){var b=document.createElement("div"),c=["perspectiveProperty","WebkitPerspective","MozPerspective","OPerspective","msPerspective"],d;for(d in c)if(b.style[c[d]]!==void 0){a.pfx=c[d].replace("Perspective","").toLowerCase();
a.prop="-"+a.pfx+"-transform";return true}return false}();""!==c.controlsContainer&&(a.controlsContainer=0<d(c.controlsContainer).length&&d(c.controlsContainer));""!==c.manualControls&&(a.manualControls=0<d(c.manualControls).length&&d(c.manualControls));c.randomize&&(a.slides.sort(function(){return Math.round(Math.random())-0.5}),a.container.empty().append(a.slides));a.doMath();r&&f.asNav.setup();a.setup("init");c.controlNav&&f.controlNav.setup();c.directionNav&&f.directionNav.setup();c.keyboard&&
(1===d(a.containerSelector).length||c.multipleKeyboard)&&d(document).bind("keyup",function(b){b=b.keyCode;if(!a.animating&&(b===39||b===37)){b=b===39?a.getTarget("next"):b===37?a.getTarget("prev"):false;a.flexAnimate(b,c.pauseOnAction)}});c.mousewheel&&a.bind("mousewheel",function(b,g){b.preventDefault();var d=g<0?a.getTarget("next"):a.getTarget("prev");a.flexAnimate(d,c.pauseOnAction)});c.pausePlay&&f.pausePlay.setup();c.slideshow&&(c.pauseOnHover&&a.hover(function(){a.pause()},function(){a.manualPause||
a.play()}),0<c.initDelay?setTimeout(a.play,c.initDelay):a.play());o&&c.touch&&f.touch();(!p||p&&c.smoothHeight)&&d(window).bind("resize focus",f.resize);setTimeout(function(){c.start(a)},200)},asNav:{setup:function(){a.asNav=!0;a.animatingTo=Math.floor(a.currentSlide/a.move);a.currentItem=a.currentSlide;a.slides.removeClass(e+"active-slide").eq(a.currentItem).addClass(e+"active-slide");a.slides.click(function(b){b.preventDefault();var b=d(this),g=b.index();!d(c.asNavFor).data("flexslider").animating&&
!b.hasClass("active")&&(a.direction=a.currentItem<g?"next":"prev",a.flexAnimate(g,c.pauseOnAction,!1,!0,!0))})}},controlNav:{setup:function(){a.manualControls?f.controlNav.setupManual():f.controlNav.setupPaging()},setupPaging:function(){var b=1,g;a.controlNavScaffold=d('<ol class="'+e+"control-nav "+e+("thumbnails"===c.controlNav?"control-thumbs":"control-paging")+'"></ol>');if(1<a.pagingCount)for(var q=0;q<a.pagingCount;q++)g="thumbnails"===c.controlNav?'<img src="'+a.slides.eq(q).attr("data-thumb")+
'"/>':"<a>"+b+"</a>",a.controlNavScaffold.append("<li>"+g+"</li>"),b++;a.controlsContainer?d(a.controlsContainer).append(a.controlNavScaffold):a.append(a.controlNavScaffold);f.controlNav.set();f.controlNav.active();a.controlNavScaffold.delegate("a, img",s,function(b){b.preventDefault();var b=d(this),g=a.controlNav.index(b);b.hasClass(e+"active")||(a.direction=g>a.currentSlide?"next":"prev",a.flexAnimate(g,c.pauseOnAction))});o&&a.controlNavScaffold.delegate("a","click touchstart",function(a){a.preventDefault()})},
setupManual:function(){a.controlNav=a.manualControls;f.controlNav.active();a.controlNav.live(s,function(b){b.preventDefault();var b=d(this),g=a.controlNav.index(b);b.hasClass(e+"active")||(g>a.currentSlide?a.direction="next":a.direction="prev",a.flexAnimate(g,c.pauseOnAction))});o&&a.controlNav.live("click touchstart",function(a){a.preventDefault()})},set:function(){a.controlNav=d("."+e+"control-nav li "+("thumbnails"===c.controlNav?"img":"a"),a.controlsContainer?a.controlsContainer:a)},active:function(){a.controlNav.removeClass(e+
"active").eq(a.animatingTo).addClass(e+"active")},update:function(b,c){1<a.pagingCount&&"add"===b?a.controlNavScaffold.append(d("<li><a>"+a.count+"</a></li>")):1===a.pagingCount?a.controlNavScaffold.find("li").remove():a.controlNav.eq(c).closest("li").remove();f.controlNav.set();1<a.pagingCount&&a.pagingCount!==a.controlNav.length?a.update(c,b):f.controlNav.active()}},directionNav:{setup:function(){var b=d('<ul class="'+e+'direction-nav"><li><a class="'+e+'prev" href="#">'+c.prevText+'</a></li><li><a class="'+
e+'next" href="#">'+c.nextText+"</a></li></ul>");a.controlsContainer?(d(a.controlsContainer).append(b),a.directionNav=d("."+e+"direction-nav li a",a.controlsContainer)):(a.append(b),a.directionNav=d("."+e+"direction-nav li a",a));f.directionNav.update();a.directionNav.bind(s,function(b){b.preventDefault();b=d(this).hasClass(e+"next")?a.getTarget("next"):a.getTarget("prev");a.flexAnimate(b,c.pauseOnAction)});o&&a.directionNav.bind("click touchstart",function(a){a.preventDefault()})},update:function(){var b=
e+"disabled";c.animationLoop||(1===a.pagingCount?a.directionNav.addClass(b):0===a.animatingTo?a.directionNav.removeClass(b).filter("."+e+"prev").addClass(b):a.animatingTo===a.last?a.directionNav.removeClass(b).filter("."+e+"next").addClass(b):a.directionNav.removeClass(b))}},pausePlay:{setup:function(){var b=d('<div class="'+e+'pauseplay"><a></a></div>');a.controlsContainer?(a.controlsContainer.append(b),a.pausePlay=d("."+e+"pauseplay a",a.controlsContainer)):(a.append(b),a.pausePlay=d("."+e+"pauseplay a",
a));f.pausePlay.update(c.slideshow?e+"pause":e+"play");a.pausePlay.bind(s,function(b){b.preventDefault();if(d(this).hasClass(e+"pause")){a.pause();a.manualPause=true}else{a.play();a.manualPause=false}});o&&a.pausePlay.bind("click touchstart",function(a){a.preventDefault()})},update:function(b){"play"===b?a.pausePlay.removeClass(e+"pause").addClass(e+"play").text(c.playText):a.pausePlay.removeClass(e+"play").addClass(e+"pause").text(c.pauseText)}},touch:function(){function b(b){j=l?d-b.touches[0].pageY:
d-b.touches[0].pageX;o=l?Math.abs(j)<Math.abs(b.touches[0].pageX-e):Math.abs(j)<Math.abs(b.touches[0].pageY-e);if(!o||500<Number(new Date)-k)b.preventDefault(),!p&&a.transitions&&(c.animationLoop||(j/=0===a.currentSlide&&0>j||a.currentSlide===a.last&&0<j?Math.abs(j)/n+2:1),a.setProps(f+j,"setTouch"))}function g(){if(a.animatingTo===a.currentSlide&&!o&&null!==j){var i=m?-j:j,l=0<i?a.getTarget("next"):a.getTarget("prev");a.canAdvance(l)&&(550>Number(new Date)-k&&20<Math.abs(i)||Math.abs(i)>n/2)?a.flexAnimate(l,
c.pauseOnAction):a.flexAnimate(a.currentSlide,c.pauseOnAction,!0)}h.removeEventListener("touchmove",b,!1);h.removeEventListener("touchend",g,!1);f=j=e=d=null}var d,e,f,n,j,k,o=!1;h.addEventListener("touchstart",function(j){a.animating?j.preventDefault():1===j.touches.length&&(a.pause(),n=l?a.h:a.w,k=Number(new Date),f=i&&m&&a.animatingTo===a.last?0:i&&m?a.limit-(a.itemW+c.itemMargin)*a.move*a.animatingTo:i&&a.currentSlide===a.last?a.limit:i?(a.itemW+c.itemMargin)*a.move*a.currentSlide:m?(a.last-a.currentSlide+
a.cloneOffset)*n:(a.currentSlide+a.cloneOffset)*n,d=l?j.touches[0].pageY:j.touches[0].pageX,e=l?j.touches[0].pageX:j.touches[0].pageY,h.addEventListener("touchmove",b,!1),h.addEventListener("touchend",g,!1))},!1)},resize:function(){!a.animating&&a.is(":visible")&&(i||a.doMath(),p?f.smoothHeight():i?(a.slides.width(a.computedW),a.update(a.pagingCount),a.setProps()):l?(a.viewport.height(a.h),a.setProps(a.h,"setTotal")):(c.smoothHeight&&f.smoothHeight(),a.newSlides.width(a.computedW),a.setProps(a.computedW,
"setTotal")))},smoothHeight:function(b){if(!l||p){var c=p?a:a.viewport;b?c.animate({height:a.slides.eq(a.animatingTo).height()},b):c.height(a.slides.eq(a.animatingTo).height())}},sync:function(b){var g=d(c.sync).data("flexslider"),e=a.animatingTo;switch(b){case "animate":g.flexAnimate(e,c.pauseOnAction,!1,!0);break;case "play":!g.playing&&!g.asNav&&g.play();break;case "pause":g.pause()}}};a.flexAnimate=function(b,g,q,h,k){if(!a.animating&&(a.canAdvance(b)||q)&&a.is(":visible")){if(r&&h)if(q=d(c.asNavFor).data("flexslider"),
	a.atEnd=0===b||b===a.count-1,q.flexAnimate(b,!0,!1,!0,k),a.direction=a.currentItem<b?"next":"prev",q.direction=a.direction,Math.ceil((b+1)/a.visible)-1!==a.currentSlide&&0!==b)a.currentItem=b,a.slides.removeClass(e+"active-slide").eq(b).addClass(e+"active-slide"),b=Math.floor(b/a.visible);else return a.currentItem=b,a.slides.removeClass(e+"active-slide").eq(b).addClass(e+"active-slide"),!1;a.animating=!0;a.animatingTo=b;c.before(a);g&&a.pause();a.syncExists&&!k&&f.sync("animate");c.controlNav&&f.controlNav.active();
		i||a.slides.removeClass(e+"active-slide").eq(b).addClass(e+"active-slide");a.atEnd=0===b||b===a.last;c.directionNav&&f.directionNav.update();b===a.last&&(c.end(a),c.animationLoop||a.pause());if(p)a.slides.eq(a.currentSlide).fadeOut(c.animationSpeed,c.easing),a.slides.eq(b).fadeIn(c.animationSpeed,c.easing,a.wrapup);else{var n=l?a.slides.filter(":first").height():a.computedW;i?(b=c.itemWidth>a.w?2*c.itemMargin:c.itemMargin,b=(a.itemW+b)*a.move*a.animatingTo,b=b>a.limit&&1!==a.visible?a.limit:b):b=
		0===a.currentSlide&&b===a.count-1&&c.animationLoop&&"next"!==a.direction?m?(a.count+a.cloneOffset)*n:0:a.currentSlide===a.last&&0===b&&c.animationLoop&&"prev"!==a.direction?m?0:(a.count+1)*n:m?(a.count-1-b+a.cloneOffset)*n:(b+a.cloneOffset)*n;a.setProps(b,"",c.animationSpeed);if(a.transitions){if(!c.animationLoop||!a.atEnd)a.animating=!1,a.currentSlide=a.animatingTo;a.container.unbind("webkitTransitionEnd transitionend");a.container.bind("webkitTransitionEnd transitionend",function(){a.wrapup(n)})}else a.container.animate(a.args,
		c.animationSpeed,c.easing,function(){a.wrapup(n)})}c.smoothHeight&&f.smoothHeight(c.animationSpeed)}};a.wrapup=function(b){!p&&!i&&(0===a.currentSlide&&a.animatingTo===a.last&&c.animationLoop?a.setProps(b,"jumpEnd"):a.currentSlide===a.last&&(0===a.animatingTo&&c.animationLoop)&&a.setProps(b,"jumpStart"));a.animating=!1;a.currentSlide=a.animatingTo;c.after(a)};a.animateSlides=function(){a.animating||a.flexAnimate(a.getTarget("next"))};a.pause=function(){clearInterval(a.animatedSlides);a.playing=!1;
		c.pausePlay&&f.pausePlay.update("play");a.syncExists&&f.sync("pause")};a.play=function(){a.animatedSlides=setInterval(a.animateSlides,c.slideshowSpeed);a.playing=!0;c.pausePlay&&f.pausePlay.update("pause");a.syncExists&&f.sync("play")};a.canAdvance=function(b){var d=r?a.pagingCount-1:a.last;return r&&0===a.currentItem&&b===a.pagingCount-1&&"next"!==a.direction?!1:b===a.currentSlide&&!r?!1:c.animationLoop?!0:a.atEnd&&0===a.currentSlide&&b===d&&"next"!==a.direction?!1:a.atEnd&&a.currentSlide===d&&0===
		b&&"next"===a.direction?!1:!0};a.getTarget=function(b){a.direction=b;return"next"===b?a.currentSlide===a.last?0:a.currentSlide+1:0===a.currentSlide?a.last:a.currentSlide-1};a.setProps=function(b,d,e){var f=function(){var e=b?b:(a.itemW+c.itemMargin)*a.move*a.animatingTo;return-1*function(){if(i)return"setTouch"===d?b:m&&a.animatingTo===a.last?0:m?a.limit-(a.itemW+c.itemMargin)*a.move*a.animatingTo:a.animatingTo===a.last?a.limit:e;switch(d){case "setTotal":return m?(a.count-1-a.currentSlide+a.cloneOffset)*
		b:(a.currentSlide+a.cloneOffset)*b;case "setTouch":return b;case "jumpEnd":return m?b:a.count*b;case "jumpStart":return m?a.count*b:b;default:return b}}()+"px"}();a.transitions&&(f=l?"translate3d(0,"+f+",0)":"translate3d("+f+",0,0)",e=void 0!==e?e/1E3+"s":"0s",a.container.css("-"+a.pfx+"-transition-duration",e));a.args[a.prop]=f;(a.transitions||void 0===e)&&a.container.css(a.args)};a.setup=function(b){if(p)a.slides.css({width:"100%","float":"left",marginRight:"-100%",position:"relative"}),"init"===
		b&&a.slides.eq(a.currentSlide).fadeIn(c.animationSpeed,c.easing),c.smoothHeight&&f.smoothHeight();else{var g,h;"init"===b&&(a.viewport=d('<div class="flex-viewport"></div>').css({overflow:"hidden",position:"relative"}).appendTo(a).append(a.container),a.cloneCount=0,a.cloneOffset=0,m&&(h=d.makeArray(a.slides).reverse(),a.slides=d(h),a.container.empty().append(a.slides)));c.animationLoop&&!i&&(a.cloneCount=2,a.cloneOffset=1,"init"!==b&&a.container.find(".clone").remove(),a.container.append(a.slides.first().clone().addClass("clone")).prepend(a.slides.last().clone().addClass("clone")));
		a.newSlides=d(c.selector,a);g=m?a.count-1-a.currentSlide+a.cloneOffset:a.currentSlide+a.cloneOffset;l&&!i?(a.container.height(200*(a.count+a.cloneCount)+"%").css("position","absolute").width("100%"),setTimeout(function(){a.newSlides.css({display:"block"});a.doMath();a.viewport.height(a.h);a.setProps(g*a.h,"init")},"init"===b?100:0)):(a.container.width(200*(a.count+a.cloneCount)+"%"),a.setProps(g*a.computedW,"init"),setTimeout(function(){a.doMath();a.newSlides.css({width:a.computedW,"float":"left",
		display:"block"});c.smoothHeight&&f.smoothHeight()},"init"===b?100:0))}i||a.slides.removeClass(e+"active-slide").eq(a.currentSlide).addClass(e+"active-slide")};a.doMath=function(){var b=a.slides.first(),d=c.itemMargin,e=c.minItems,f=c.maxItems;a.w=a.width();a.h=b.height();a.boxPadding=b.outerWidth()-b.width();i?(a.itemT=c.itemWidth+d,a.minW=e?e*a.itemT:a.w,a.maxW=f?f*a.itemT:a.w,a.itemW=a.minW>a.w?(a.w-d*e)/e:a.maxW<a.w?(a.w-d*f)/f:c.itemWidth>a.w?a.w:c.itemWidth,a.visible=Math.floor(a.w/(a.itemW+
		d)),a.move=0<c.move&&c.move<a.visible?c.move:a.visible,a.pagingCount=Math.ceil((a.count-a.visible)/a.move+1),a.last=a.pagingCount-1,a.limit=1===a.pagingCount?0:c.itemWidth>a.w?(a.itemW+2*d)*a.count-a.w-d:(a.itemW+d)*a.count-a.w):(a.itemW=a.w,a.pagingCount=a.count,a.last=a.count-1);a.computedW=a.itemW-a.boxPadding};a.update=function(b,d){a.doMath();i||(b<a.currentSlide?a.currentSlide+=1:b<=a.currentSlide&&0!==b&&(a.currentSlide-=1),a.animatingTo=a.currentSlide);if(c.controlNav&&!a.manualControls)if("add"===
		d&&!i||a.pagingCount>a.controlNav.length)f.controlNav.update("add");else if("remove"===d&&!i||a.pagingCount<a.controlNav.length)i&&a.currentSlide>a.last&&(a.currentSlide-=1,a.animatingTo-=1),f.controlNav.update("remove",a.last);c.directionNav&&f.directionNav.update()};a.addSlide=function(b,e){var f=d(b);a.count+=1;a.last=a.count-1;l&&m?void 0!==e?a.slides.eq(a.count-e).after(f):a.container.prepend(f):void 0!==e?a.slides.eq(e).before(f):a.container.append(f);a.update(e,"add");a.slides=d(c.selector+
		":not(.clone)",a);a.setup();c.added(a)};a.removeSlide=function(b){var e=isNaN(b)?a.slides.index(d(b)):b;a.count-=1;a.last=a.count-1;isNaN(b)?d(b,a.slides).remove():l&&m?a.slides.eq(a.last).remove():a.slides.eq(b).remove();a.doMath();a.update(e,"remove");a.slides=d(c.selector+":not(.clone)",a);a.setup();c.removed(a)};f.init()};d.flexslider.defaults={namespace:"flex-",selector:".slides > li",animation:"fade",easing:"swing",direction:"horizontal",reverse:!1,animationLoop:!0,smoothHeight:!1,startAt:0,
			slideshow:!0,slideshowSpeed:7E3,animationSpeed:600,initDelay:0,randomize:!1,pauseOnAction:!0,pauseOnHover:!1,useCSS:!0,touch:!0,video:!1,controlNav:!0,directionNav:!0,prevText:"Previous",nextText:"Next",keyboard:!0,multipleKeyboard:!1,mousewheel:!1,pausePlay:!1,pauseText:"Pause",playText:"Play",controlsContainer:"",manualControls:"",sync:"",asNavFor:"",itemWidth:0,itemMargin:0,minItems:0,maxItems:0,move:0,start:function(){},before:function(){},after:function(){},end:function(){},added:function(){},
		removed:function(){}};d.fn.flexslider=function(h){h=h||{};if("object"===typeof h)return this.each(function(){var a=d(this),c=a.find(h.selector?h.selector:".slides > li");1===c.length?(c.fadeIn(400),h.start&&h.start(a)):void 0===a.data("flexslider")&&new d.flexslider(this,h)});var k=d(this).data("flexslider");switch(h){case "play":k.play();break;case "pause":k.pause();break;case "next":k.flexAnimate(k.getTarget("next"),!0);break;case "prev":case "previous":k.flexAnimate(k.getTarget("prev"),!0);break;
		default:"number"===typeof h&&k.flexAnimate(h,!0)}}})(jQuery);

		/* **********************************************
		Begin smooth-scroll.js
		********************************************** */

		$(document).ready(function() {
			function filterPath(string) {
				return string
				.replace(/^\//,'')
				.replace(/(index|default).[a-zA-Z]{3,4}$/,'')
				.replace(/\/$/,'');
			}

			var locationPath = filterPath(location.pathname);

			// use the first element that is "scrollable"
			function scrollableElement(els) {
				for (var i = 0, argLength = arguments.length; i <argLength; i++) {
					var el = arguments[i],
					$scrollElement = $(el);
					if ($scrollElement.scrollTop()> 0) {
						return el;
					} else {
						$scrollElement.scrollTop(1);
						var isScrollable = $scrollElement.scrollTop()> 0;
						$scrollElement.scrollTop(0);
						if (isScrollable) {
							return el;
						}
					}
				}
				return [];
			}
			var scrollElem = scrollableElement('html', 'body');

			$('a[href*=#]').each(function() {
				var thisPath = filterPath(this.pathname) || locationPath;
				if (locationPath == thisPath && (location.hostname == this.hostname || !this.hostname) && this.hash.replace(/#/,'')) {
					var $target = $(this.hash), target = this.hash;
					if (target && $target.length) {
						var targetOffset = $target.offset().top;
						$(this).bind('click', function(event) {
							event.preventDefault();
						$(scrollElem).animate({scrollTop: targetOffset}, 400, function() {
							location.hash = target;
						});
					});
				}
			}
		});
	});

	/* **********************************************
	Begin scripts.js
	********************************************** */

	var CURRWIDTH, PREVWIDTH, SPEC, setSpec;

	//Track window size
	setSpec = function() {
		var previous = SPEC;
		SPEC = $(document).width() > 745 ? 'large' : 'small';
		PREVWIDTH = CURRWIDTH;
		CURRWIDTH = $(document).width();
		return CURRWIDTH;
	};

	//Form validation
	var form = (function() {
		var t = {};
		t.container = null;
		t.checkEmail = function(value) {
			return (/^((([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+(\.([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+)*)|((\x22)((((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(([\x01-\x08\x0b\x0c\x0e-\x1f\x7f]|\x21|[\x23-\x5b]|[\x5d-\x7e]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(\\([\x01-\x09\x0b\x0c\x0d-\x7f]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))))*(((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(\x22)))@((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.?$/i).test(value);
		};
		t.setupEvents = function() {
			t.container.bind('submit', function(e) {
				e.preventDefault();
				var error = false;
				$('.required', t.container).removeClass('error');
				$('.successmsg', t.container).remove();
				$('.message.errormsg', t.container).hide();
				$('.required', t.container).each(function() {
					var that = $(this);
					if(that.val() === '' || (that.attr('type') === 'email' && t.checkEmail(that.val()) === false)) {
						error = true;
						that.addClass('error');
					}
				});
				if(error === false) {
					//TODO: Send the form
					//t.container.unbind('submit');
					//t.container.submit();
					$('.error', t.container).removeClass('error');
					$('div.submit', t.container).append('<p class="message successmsg">Thank You! Your inquiry has been sent.</p>');
					t.container.each(function() {
						this.reset();
					});
				} else {
					$('.message.errormsg', t.container).show();
				}
			});

			$('.required').blur(function() {
				var that = $(this);
				if(that.attr('type') === 'email' && t.checkEmail(that.val()) === true) {
					that.removeClass('error');
				} else if(that.attr('type') !== 'email' && that.val() !== '') {
					that.removeClass('error');
				}
			});
		};
		t.init = function() {
			t.container = $('form#contactform');
			if(t.container.length > 0) {
				t.setupEvents();
			}
		};
		return t;
	})();

	//External and pdf links
	var links = (function() {
		var t = {};
		t.appriseExternal = function(link) {
			var message = '<p>You are about to open a new page which is not on the CNL Securities website.'+
			'<br /><br />Click "OK" to proceed to the page you have requested.'+
			'<br />Click "Cancel" to return to the previous page.</p>';
		link.apprise(message, {'confirm': true, 'showFooter': true}, function(r) {
			if(r === true) {
				window.open(link.attr('href'));
			}
		});
	};
	t.mobileExternal = function(link) {
		var answer = confirm("You are about to open a new page which is not on the CNL Securities website.\n\nClick \"OK\" to proceed to the page you have requested. Click \"Cancel\" to return to the previous page.\n\n&copy; 2017 CNL Securities Corp. All rights reserved.");
		if(answer) {
			window.open(link.attr('href'));
		}
	};
	t.setupEvents = function() {
		$('a[rel=external]').click(function(e) {
			e.preventDefault();
			var link = $(this);
			var open = SPEC === 'large' ? t.appriseExternal(link) : t.mobileExternal(link);
		});
	};
	t.init = function() {
		$('#wrapper a').each(function() {
        	if(typeof $(this).attr('href') === "undefined"){
            	//do nothing
            }else{
              var a, pdf, email;
              a = new RegExp('/' + window.location.host + '/');
              email = new RegExp('mailto');
              pdf = new RegExp('.pdf');
              if(!email.test(this.href) && (!a.test(this.href) || pdf.test(this.href))) {
                  $(this).attr('target', '_blank');
              }
              if(!email.test(this.href) && !a.test(this.href)) {
                  $(this).attr('rel', 'external');
              }
            }
		});
		t.setupEvents();
	};
	return t;
})();

//Filter Investor-Approved Materials
var tools_filter = (function() {
	var t = {};
	t.items = null;
	t.has_params = false;
	t.change = function(selected) {
		var selected_array = [];
		for(var i in selected) {
			if(selected[i] === true) {
				selected_array.push(i);
			}
		}
		t.items.each(function() {
			var item = $(this);
			var tags = $(this).attr('data-tags').split(', ');
			var match = t.intersect(tags, selected_array);
			if(match.length > 0) {
				item.show();
			} else {
				item.hide();
			}
		});
		$.cookie('tools_filter', selected_array.join(', '));
	};
	t.getParameterByName = function(name) {
		name = name.replace(/[\[]/, "\\\[").replace(/[\]]/, "\\\]");
		var regexS = "[\\?&]" + name + "=([^&#]*)";
		var regex = new RegExp(regexS);
		var results = regex.exec(window.location.search);
		if(results == null) {
			return null;
		} else {
			t.has_params = true;
			return decodeURIComponent(results[1].replace(/\+/g, " "));
		}
	};
	t.intersect = function(a, b) {
		var result = [];
		for(var i in b) {
			if($.inArray(b[i], a) != -1) {
				result.push(b[i]);
			}
		}
		return result;
	};
	t.init = function() {
		t.items = $('.tool');
		if(t.items.length > 0) {
			$('.filter input[type=checkbox]').checkGui({
				change_callback: t.change
			});
			var params = {
				ai: t.getParameterByName('ai'),
				bdcs: t.getParameterByName('bdcs'),
				reits: t.getParameterByName('reits')
			};
			var all = t.getParameterByName('all');
			if(t.has_params === true) {
				if(all) {
					params = {
						ai: 1,
						bdcs: 1,
						reits: 1
					};
				}
				for(var i in params) {
					if(params[i] === null) {
						var input = $('.filter .checkbox input[name='+i+']');
						input.siblings('label').trigger('click');
					}
				}
			} else if($.cookie('tools_filter')) {
				var selected = $.cookie('tools_filter').split(', ');
				$('.filter .checkbox').each(function() {
					var name = $(this).children('input').attr('name');
					if($.inArray(name, selected) == -1) {
						$(this).children('label').trigger('click');
					}
				});
			}
		}
	};
	return t;
})();

//Risk factors message
var risk_factors = (function() {
	var t = {};
	t.current = null;
	t.nonAP = false;
	t.AP = false;
	t.appriseWindow = function() {
	$(window).apprise(t.message(), {'confirm': true, 'showFooter': true}, function(r) {
		if(r === true) {
			//Let them go
			$.cookie(t.current, 'TRUE', {path: '/', expires: 30});
		} else {
			//Send them packin
			window.history.go(-1);
		}
	});
	t.nonAP = false;
	t.AP = false;
};
t.message = function() {
	var message = [];
	
	
	if(t.AP === true || t.nonAP === true) {

		if(t.nonAP === true) {
	//		message.push('<p style="max-width: 400px">If you are an Ameriprise Financial Services, Inc. Advisor please DO NOT utilize this form. A separate subscription agreement has been created for Amerprise use only.</p>');
		}
		if(t.AP === true) {
			message.push('<p style="max-width: 400px">This subscription agreement is for Ameriprise Financial Services, Inc. use only and should be used in conjunction with the '+t.current+' <a href="'+t.docURL+'">prospectus</a>.</p>');
		}
		
		
		if(t.current == "Corporate Capital Trust II LPL")
		{
			message.push('<p style="max-width: 400px">');
			message.push('This subscription agreement is for LPL Financial use only and should be used in conjunction with the Corporate Capital Trust II <a href="/file_id/015G000000uvhwl"> prospectus</a>.');
			message.push('</p>');
			message.push('<p style="max-width: 400px">');
			message.push('There are significant risks and investment costs associated with investing in Corporate Capital Trust II. This investment is also not suitable for all investors. An investor should read the <a href="/file_id/015G000000uvhwl">prospectus</a> carefully before investing in order to fully understand the implications, risks and costs involved in this offering.');
			message.push('</p>');
		}
		else
		{
			if(SPEC === 'large') {
				message.push('<p style="max-width: 400px">');
				message.push('There are significant risks and investment costs associated with investing in '+t.current+'. This investment is also not suitable for all investors. An investor should read the <a href="'+t.docURL+'">prospectus</a> carefully before investing in order to fully understand the implications, risks and costs involved in this offering.');
				message.push('</p>');
			} else {
				message.push('<p style="max-width: 400px">');
				message.push('There are significant risks and investment costs associated with investing in '+t.current+'. This investment is also not suitable for all investors. An investor should read the <a href="'+t.docURL+'">prospectus</a> carefully before investing in order to fully understand the implications, risks and costs involved in this offering.');
				message.push('</p>');
			}
		}
	
	}
	else
	{
	
		if(t.current == "Corporate Capital Trust II")
		{
			
			message.push('<p style="max-width: 400px">Corporate Capital Trust II is not available to residents of Massachusetts.</p>');
			message.push('<p style="max-width: 400px">This website is not for use in MA.</p>');
			message.push('<p style="max-width: 400px">');
			message.push('There are significant risks and investment costs associated with an investment in '+t.current+'. This investment is also not suitable for all investors. To view a summary of these risks and costs,  <a target="_blank" href="http://www.cnlsecurities.com/quick-links/prospectus.stml#cctii-risk">click here</a>. This material must be read in conjunction with the <a target="_blank" href="'+t.docURL+'">prospectus</a>  to fully understand the implications and risks involved in this offering. The <a target="_blank" href="'+t.docURL+'">prospectus</a> should be read carefully before investing.');
			message.push('</p>');
		}
		else if(t.current == "Corporate Capital Trust")
		{
			message.push('<p style="max-width: 400px">');
			message.push('There are significant risks and investment costs associated with investing in '+t.current+'. This investment is also not suitable for all investors.  To view a summary of these risks and investment costs, <a target="_blank" href="http://www.cnlsecurities.com/quick-links/prospectus.stml#cct-risk">click here</a>. This material must be read in conjunction with the <a target="_blank" href="'+t.docURL+'">prospectus</a> in order to fully understand the implications and risks involved in this offering. The <a target="_blank" href="'+t.docURL+'">prospectus</a> should be read carefully before investing.');

			message.push('</p>');
		}
		else if(t.current == "Corporate Capital Subscription")
		{
				message.push('<p style="max-width: 400px">');
				message.push('There are significant risks and investment costs associated with investing in Corporate Capital Trust. This investment is also not suitable for all investors. An investor should read the <a href="/file_id/015G0000004Rcdq">prospectus</a> carefully before investing in order to fully understand the implications, risks and costs involved in this offering.');                                      
				message.push('</p>');
		}
		else if(t.current == "CNL Strategic Capital")
		{
				message.push('<p style="max-width: 400px">');
				message.push('There are significant risks and costs associated with an investment in CNL Strategic Capital. This investment is considered speculative and is not suitable for all investors. To view a summary of these risks and costs, <a href="/file_id/0150f000025G1Yb/">click here</a>. This material must be read in conjunction with the prospectus to fully understand the risks involved in this offering. Carefully read the <a href="/file_id/0150f000025G1Yb/">prospectus</a> before investing.');                                      
				message.push('</p>');
		}
		else if(t.current == "Privacy Policy")
		{
				message.push('<p style="max-width: 400px">');
				message.push('Our website uses cookies to help us better understand how our site is used and to tailor advertising. By clicking OK and continuing to use this website, you are consenting to the use of cookies. <a href="/quick-links/privacy-policy.stml">View privacy policy</a>.');
				message.push('</p>');
		}        
		else
		{
	
			if(SPEC === 'large') {
			
				message.push('<p style="max-width: 400px">');
			//	message.push('This website is not for use in Ohio.');
				message.push('</p>');
			
				message.push('<p style="max-width: 400px">');
				message.push('There are significant risks and investment costs associated with investing in '+t.current+'. This investment is considered speculative and is not suitable for all investors. To view a summary of these risks and costs, as outlined in the prospectus, <a target="_blank" href="'+t.docURL+'">click here</a>. This material must be read in conjunction with the <a target="_blank" href="'+t.docURL+'">prospectus</a>, which includes the full risk factors, in order to fully understand the implication and risks involved in this offering. To read a copy of the prospectus, <a target="_blank" href="'+t.docURL+'">click here</a>.');
				//message.push('This material must be read in conjunction with the prospectus in order to fully understand the implications and risks involved in this offering. To read a copy of the prospectus, <a target="_blank" href="'+t.docURL+'">click here</a>.');
				message.push('</p>');
			} else {
				message.push('<p style="max-width: 400px">');
			//	message.push('This website is not for use in Ohio.');
				message.push('</p>');
				
				message.push('<p style="max-width: 400px">');
				message.push('There are significant risks and investment costs associated with investing in '+t.current+'. This investment is also not suitable for all investors. To view a summary of these risks and costs, as outlined in the prospectus, <a target="_blank" href="'+t.docURL+'">click here</a>. This material must be read in conjunction with the <a target="_blank" href="'+t.docURL+'">prospectus</a> in order to fully understand the implication and risks involved in this offering. To read a copy of the prospectus, <a target="_blank" href="'+t.docURL+'">click here</a>.');
				message.push('</p>');
			}
		
		}
		
		
	}
	
	

	
	
	
	
	

	return message.join('');
};
t.pages = function() {
	return {
		'reit-global-growth-trust_page': 'CNL Growth Properties',
		'reit-global-income-trust_page': 'Global Income Trust',
		'reit-cnl-healthcare-trust_page': 'CNL Healthcare Properties II',
		'bdc-corporate-capital-trust_page': 'Corporate Capital Trust',
		'bdc-corporate-capital-trust-ii': 'Corporate Capital Trust II',
		'reit-customized-allocations_page': 'Global Growth Trust and Global Income Trust',
		'cef-cnl-energy-total-return-fund_page':'CNL Strategic Capital',
		'cnl_strategic_capital_page':'CNL Strategic Capital',
        'privacy-policy':'Privacy Policy'
	};
};

t.docs = function() {
	return {
		'reit-global-growth-trust_page': '/utilities/SFDC_CNL_get.php?file_id=015G0000001TKnm',
		'reit-global-income-trust_page': '/utilities/SFDC_CNL_get.php?file_id=015G0000001R4E5',
		//'reit-cnl-healthcare-trust_page': '/utilities/SFDC_CNL_get.php?file_id=015G0000001Tkvq',
		'reit-cnl-healthcare-trust_page': '/file_id/015G0000015PsXC/',
		//'bdc-corporate-capital-trust_page': ' /utilities/SFDC_CNL_get.php?file_id=015G0000001Tnva',
		//'bdc-corporate-capital-trust_page': '/utilities/SFDC_CNL_get.php?file_id=015G0000004Rcdq',
		'bdc-corporate-capital-trust_page': '/file_id/015G0000004Rcdq',
		'bdc-corporate-capital-trust-ii': '/file_id/015G000000uvhwl/',
		'reit-customized-allocations_page': 'Global Growth Trust and Global Income Trust',
		'cef-cnl-energy-total-return-fund_page':'/file_id/015G0000004Rcdq',
		'cnl_strategic_capital_page':'/file_id/0150f000025G1Yb/'
	};
};


t.preAppriseWindow = function(link) {
$(window).apprise(t.message(), {'confirm': true, 'showFooter': true}, function(r) {
	if(r === true) {
		//Let them go
		$.cookie(t.current, 'TRUE', {path: '/', expires: 30});

		//alert(link.attr('href'));
		var ie = (function(){
			var undef,
			v = 3,
			div = document.createElement('div'),
			all = div.getElementsByTagName('i');
			while (
			div.innerHTML = '<!--[if gt IE ' + (++v) + ']><i></i><![endif]-->',
			all[0]
			);
			return v > 4 ? v : undef;
		}());

		if(ie)
		{
			window.location.href(link.attr('href'));
		}
		else
			{
				window.open(link.attr('href'));
			}
			//window.location.href(link.attr('href'));
		} else {
			//Send them packin
			return false;
		}
	});
};
t.init = function() { 
	var id = $('body').attr('id');
	var myClass = $('body').attr('class');
	//console.log(myClass);
	//t.current = t.pages()[id];
	t.current = "Privacy Policy";
	if(myClass && myClass==' noPopup') t.current = "";
	t.docURL = t.docs()[id];
	if(t.current) {
		if(!$.cookie(t.current)) {
			t.appriseWindow();
		} else {
			// else if there is a cookie it resets the cookie
			$.cookie(t.current, 'TRUE', {path: '/', expires: 30});
		}
	}

	$('a.warn').bind('click', function(e) {
		t.current = $(this).attr('data-product');

		switch(t.current)
		{
			case "CNL Growth Properties":
			t.docURL = "/utilities/SFDC_CNL_get.php?file_id=015G0000001TKnm";
			break;
			case "Global Income Trust":
			t.docURL = "/utilities/SFDC_CNL_get.php?file_id=015G0000001R4E5";
			break;
			case "CNL Healthcare Properties II":
			//t.docURL = "/utilities/SFDC_CNL_get.php?file_id=015G0000001Tkvq";
			t.docURL = "/file_id/015G0000015PsXC/";
			break;
			case "Corporate Capital Trust":
			//t.docURL = "/utilities/SFDC_CNL_get.php?file_id=015G0000001Tnva";
			//t.docURL = "/utilities/SFDC_CNL_get.php?file_id=015G0000004Rcdq";
			t.docURL = "/file_id/015G0000004Rcdq/";
			case "Corporate Capital Trust II":
			t.docURL = "/file_id/015G000000uvhwl/";
			break;
		}


		if($(this).hasClass('ameriprise')) {
			t.AP = true;
		}
		if($(this).hasClass('nonameriprise')) {
			t.nonAP = true;
		}

		if(!$.cookie('killInternalPopup')) {
			e.preventDefault();
			t.preAppriseWindow($(this));
			t.nonAP = false;
			t.AP = false;
		} else {
			// else if there is a cookie it resets the cookie
			$.cookie('killInternalPopup', 'TRUE', {path: '/', expires: 30});
		}
	});
};
return t;
})();

$(function(){
	$('.interior aside, .single-column').append('<div class="returntop" tabindex="-1"><div class="returnwrap"><a href="#">Return to top</a></div></div>');
	var return_to_top = $('.interior aside .returntop, .single-column .returntop');
	$('a', return_to_top).on('click', function(e) {
		e.preventDefault();
		$('body,html,document').animate({
			scrollTop: 0
		}, 500);
	})

	$(window).scroll(function() {
		var scrollTop = $(window).scrollTop();
		if(scrollTop >= 350 && !return_to_top.hasClass('show')) {
			return_to_top.addClass('show');
		}
		if(scrollTop <= 350 && return_to_top.hasClass('show')) {
			return_to_top.removeClass('show');
		}
	});

	setSpec();
	$(window).resize(function() {
		return setSpec();
	});

	form.init();
	links.init();
	tools_filter.init();
	risk_factors.init();

	setTimeout(function() {
		$('.flexslider').flexslider({
			manualControls: ".flex-control-nav li span",
			slideshowSpeed: 12000
		});
	}, 500);

	$('.formstable h2').click(function() {
		$(this).toggleClass('toggled').next('ul').slideToggle();
	});
	if($('.formstable').length > 0 && window.location.hash) {
		var selected_table = $(window.location.hash);
		selected_table.trigger('click');
	}
    
    $('.formstable.stack h2').click(function() {
		$(this).toggleClass('toggled').next('.collapseStack').slideToggle();
	});
	if($('.formstable.stack').length > 0 && window.location.hash) {
		var selected_table = $(window.location.hash);
		selected_table.trigger('click');
	}

	$('#resetform').click(function(e){
		e.preventDefault();
		$('#contentint form').get(0).reset();
		$('p.successmsg').remove();
		$('p.errormsg').hide();
		$('form .error').removeClass('error');
	});

	$('select').selectGui();

	if (!Modernizr.input.placeholder) {
		$('input[placeholder]').each(function() {
			$(this).hint();
		});
	}

	$('#search').hide();

	$('.return').hide();
	$("#searchbtn").click(function(e){
		e.preventDefault();
		$("#search").slideToggle(300);
	});

	$('#supplement li.toggle').click(function(e) {
		e.preventDefault();
		$('body').toggleClass('active_nav');
		$('.return').fadeToggle();
	});

	$('.return').click(function(a) {
		a.preventDefault();
		$('body').toggleClass('active_nav');
		$('.return').fadeToggle();
	});

	function filterPath(string) {
		return string
		.replace(/^\//,'')
		.replace(/(index|default).[a-zA-Z]{3,4}$/,'')
		.replace(/\/$/,'');
	}

	$('.ie6 #mainnav li').hover(function() {
		$(this).children('ul').show();
	}, function() {
		$(this).children('ul').hide();
	});

	var downloadbox = $('.downloadbox');
	if(downloadbox.length > 0) {
		$('.share_drop', downloadbox).hover(function() {
			$(this).children('.social_drop').fadeIn();
		}, function() {
			$('.social_drop', downloadbox).fadeOut();
		});
	}

	$('.workshops a.nav').unbind('click');
	$('.workshops a.nav').bind('click', function(e) {
		e.preventDefault();
		if(!$(this).hasClass('current')) {
			var current = $('.workshops a.nav.current').attr('href');
			var id = $(this).attr('href');
			$('.workshops a.nav').removeClass('current')
			$(this).addClass('current');

			if(SPEC === 'large') {
				$(current).children('.info').fadeOut();
				$(id).children('.info').fadeIn();
			} else {
				$(current).children('.info').slideUp();
				$(id).children('.info').slideDown();

				setTimeout(function() {
					$('body,html,document').animate({
						scrollTop: $(id).offset().top
					}, 200);
				}, 400);
			}
		}
	});

	$('#timeline a.nav').unbind('click');
	$('#timeline a.nav').bind('click', function(e) {
		e.preventDefault();
		if(!$(this).parents('.item').hasClass('current')) {
			var current = $('#timeline .current');
			var next = $(this).parents('.item');
			current.removeClass('current')
			next.addClass('current');

			current.children('.event').slideUp();
			next.children('.event').slideDown();

			if(SPEC === 'small') {
				setTimeout(function() {
					$('body,html,document').animate({
						scrollTop: next.offset().top
					}, 200);
				}, 400);
			}
		}
	});

	$('.interior aside li a').append('<b />');

	$('.interior blockquote').append('<b class="l" /><b class="r" />');

	//Add openers for main nav
	$('#mainnav li:has("ul") > a').append('<b />');
	$('#mainnav a').live('click', function(e) {
		if(e.srcElement.nodeName === 'B') {
			e.preventDefault();
			var li = $(this).parent();
			li.toggleClass('current').siblings('li').removeClass('current');
			return false;
		} else {
			$('body').removeClass('active_nav');
			$('.return').hide();
			return true;
		}
	});
});

//Custom checkbox
(function ($) {
	$.fn.checkGui = function (opts) {
		var selected = {};
		var options = $.extend({
			change_callback: function(selected) {
				//console.log(selected);
			}
		}, opts);
		return this.each(function () {
			var t = {};
			t.box = $(this);
			t.select = null;
			t.selected = true;
			t.setupEvents = function() {
				t.select.click(function(e) {
					e.preventDefault();
					t.selected = t.selected === true ? false : true;
					t.toggleCheck();
				});
				t.label.click(function(e) {
					e.preventDefault();
					t.select.trigger('click');
				});
			};
			t.setupViews = function() {
				var klass = 'check_gui';
				if(!t.box.attr('checked')) {
					klass += ' off';
					t.selected = false;
				}
				t.box.after('<span class="'+klass+'"></span>');
				t.box.hide();
				t.select = t.box.next('.check_gui');
				t.label = t.box.prev('label');
				selected[t.box.attr('name')] = t.selected;
			};
			t.toggleCheck = function() {
				if(t.selected === true) {
					t.select.removeClass('off');
					t.box.attr('checked', 'checked');
				} else {
					t.select.addClass('off');
					t.box.removeAttr('checked');
				}
				selected[t.box.attr('name')] = t.selected;
				if(options.change_callback) {
					options.change_callback(selected);
				}
			};
			t.setup = function() {
				t.setupViews();
				t.setupEvents();
			};
			t.setup();
		});
	};
})(jQuery);

// Apprise 1.5 by Daniel Raftery
// http://thrivingkings.com/apprise
//
// Conversion to jQuery plugin by Adam Bezulski
// http://www.bezulski.com

(function ($) {

	$.apprise = {
		defaults: {
			'confirm': false, 		// Shows OK and Cancel buttons
			'verify': false, 		// Shows Yes and No buttons
			'input': false, 		// Returns with user inputed text
			'animate': false, 		// Groovy animation (can true or number, default is 400)
			'txtOK': 'OK',			// Text for OK
			'txtCancel': 'Cancel',	// Text for Cancel
			'txtYes': 'Yes',		// Text for Yes
			'txtNo': 'No',			// Text for No
			'showFooter': false			// Copyright for GIT
		}
	};
	$.fn.extend({
		apprise: function (string, options, callback) {
			var args = $.fn.extend({}, $.apprise.defaults, options);

			if (args) {
				for (var index in args){
					if (typeof args[index] == "undefined") args[index] = defaults[index];
				}
			}

			var aHeight = $(document).height();
			var aWidth = $(document).width();
			$('body').append('<div class="appriseOverlay" id="aOverlay"></div>');
			$('.appriseOverlay').css('height', aHeight).css('width', aWidth).fadeIn(1);
			$('body').append('<div class="appriseOuter"></div>');
			$('.appriseOuter').append('<div class="appriseInner"></div>');
			$('.appriseInner').append(string);
			$('.appriseOuter').css("left", ($(window).width() - $('.appriseOuter').width()) / 2 + $(window).scrollLeft() + "px");

			if (args) {
				if (args['animate']) {
					var aniSpeed = args['animate'];
					if (isNaN(aniSpeed)) { aniSpeed = 1; }
					$('.appriseOuter').css('top', '-200px').show().animate({ top: "100px" }, aniSpeed);
				} else {
					$('.appriseOuter').css('top', '100px').fadeIn(1);
				}
			} else {
				$('.appriseOuter').css('top', '100px').fadeIn(1);
			}

			if (args) {
				if (args['input']) {
					$('.appriseInner').append('<div class="aInput"><input type="text" class="aTextbox" t="aTextbox" /></div>');
					$('.aTextbox').focus();
				}
			}

			$('.appriseInner').append('<div class="aButtons"></div>');
			if (args) {
				if (args['confirm'] || args['input']) {
					$('.aButtons').append('<button value="ok" class="btn">' + args.txtOK + '</button>');
					$('.aButtons').append('<button value="cancel" class="btn">' + args.txtCancel + '</button>');
				} else if (args['verify']) {
					$('.aButtons').append('<button value="ok" class="btn">' + args.txtYes + '</button>');
					$('.aButtons').append('<button value="cancel" class="btn">' + args.txtNo + '</button>');
				} else {
					$('.aButtons').append('<button value="ok" class="btn">' + args.txtOK + '</button>');
				}
			} else {
				$('.aButtons').append('<button value="ok" class="btn">' + args.txtOK + '</button>');
			}

			if(args && args['showFooter'] === true) {
				
				/////$('.appriseInner').append('<p class="copyright">&copy; 2017 CNL Securities Corp. All Rights Reserved.</p>');
				//console.log(string, options, callback);
				if(string.indexOf("CNL Strategic Capital") !== -1){
					//2017 CNL Securities Corp. All Rights Reserved. 2017 CNL Securities Corp. All Rights Reserved.
					//$('.appriseInner').append('<p class="copyright">&copy; 2017 CNL Securities Corp. All Rights Reserved.</p>');
				}else{
					
					//$('.appriseInner').append('<p class="copyright">&copy; 2017 CNL Securities Corp. All Rights Reserved.</p>');
				}
				
			}

			$(document).keypress(function (e) {
				if ($('.appriseOverlay').is(':visible')) {
					if (e.keyCode == 13) {
						$('.aButtons > button[value="ok"]').click();
					}
				}
			});

			var aText = false;
			$('.aTextbox').keyup(function ()
			{ aText = $(this).val(); });

			$('.aButtons > button').click(function () {
				$('.appriseOverlay').remove();
				$('.appriseOuter').remove();
				if (callback) {
					var wButton = $(this).attr("value");
					if (wButton == 'ok') {
						if (args) {
							if (args['input'])
							{ callback(aText); }
							else
								{ callback(true); }
							}
							else
								{ callback(true); }
							}
							else if (wButton == 'cancel')
								{ callback(false); }
							}
						});
					}
				});
			})(jQuery);
   
